<?php

namespace Drupal\commerce_dias_redirect\Plugin\Commerce\PaymentGateway;

use Drupal\commerce_payment\Entity\PaymentGatewayInterface;
use Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayBase;
use Drupal\commerce_payment\Entity\PaymentInterface;
use Drupal\commerce_order\Entity\OrderInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\commerce_dias_redirect\DiasApiService;

/**
 * Provides the Off-site DIAS payment gateway.
 *
 * @CommercePaymentGateway(
 *   id = "dias_redirect",
 *   label = @Translation("DIAS Payment Redirect"),
 *   display_label = @Translation("DIAS Payment Redirect"),
 *   forms = {
 *     "offsite-payment" =
 *   "Drupal\commerce_dias_redirect\PluginForm\OffsiteRedirect\DiasPaymentRedirectForm",
 *   },
 *   payment_method_types = {"credit_card"},
 *   credit_card_types = {
 *     "amex", "dinersclub", "discover", "maestro", "mastercard", "visa",
 *   },
 *   requires_billing_information = FALSE,
 * )
 */
class DiasPaymentRedirect extends OffsitePaymentGatewayBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
        'api_order_registration_url' => '',
        'api_get_order_status_url' => '',
        'username' => '',
        'password' => '',
      ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    $form['api_order_registration_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API url for registering an order to DIAS.'),
      '#default_value' => $this->configuration['api_order_registration_url'],
      '#required' => TRUE,
    ];

    $form['api_get_order_status_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API url for retrieving status for the DIAS registered order.'),
      '#default_value' => $this->configuration['api_get_order_status_url'],
      '#required' => TRUE,
    ];

    $form['username'] = [
      '#type' => 'textfield',
      '#required' => TRUE,
      '#title' => $this->t('Username'),
      '#description' => $this->t('The username of the merchant.'),
      '#default_value' => $this->configuration['username'],
    ];

    $form['password'] = [
      '#type' => 'textfield',
      '#required' => TRUE,
      '#title' => $this->t('Password'),
      '#description' => $this->t('The password of the merchant.'),
      '#default_value' => $this->configuration['password'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    if (!$form_state->getErrors()) {
      $values = $form_state->getValue($form['#parents']);
      $this->configuration['api_order_registration_url'] = $values['api_order_registration_url'];
      $this->configuration['api_get_order_status_url'] = $values['api_get_order_status_url'];
      $this->configuration['username'] = $values['username'];
      $this->configuration['password'] = $values['password'];
    }
  }

}
